@@ -5,10 +5,10 @@
 //CLASS
     class IFdSeek: public IFdStreambuf
     {
-        typedef std::streambuf::pos_type        pos_type;
-        typedef std::streambuf::off_type        off_type;
-        typedef std::ios::seekdir               seekdir;
-        typedef std::ios::openmode              openmode;
+        using pos_type = std::streambuf::pos_type;
+        using off_type = std::streambuf::off_type;
+        using seekdir = std::ios::seekdir;
+        using openmode = std::ios::openmode;
 
         public:
             IFdSeek(int fd);
